
/*
 * FSDB_GO/src/fsdb_writer_test.go
 * Copyright (c) 2016-2017 John Heidemann
 * All rights reserved.                                            
 *                                                                
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 */

package fsdb_test

import (
	"bufio"
	"bytes"
	"fmt"
	"fsdb"
	"io"
	"os"
//	"io/ioutil"
//	"strings"
	"testing"
)

type classTableW struct {
	Sid int `col:"sid"`
	Name string `col:"sname"`
}

const (
	sample_fsdb = `#fsdb -F t sid sname
1	dave
2	john
3	sugata
`
)

var sampleClassTable = []classTableW {
	classTableW { 1, "dave" },
	classTableW { 2, "john" },
	classTableW { 3, "sugata" },
	}

type nopWriteCloser struct {
	io.Writer
}
func (w nopWriteCloser) Close() error {
	return nil
}

func NopWriteCloser(w io.Writer) io.WriteCloser {
	return nopWriteCloser{w}
}

func TestWriter(t *testing.T) {
	var buf = new(bytes.Buffer)
	t.Log("TestWriter")
	out, err := fsdb.NewFsdbWriter(NopWriteCloser(bufio.NewWriter(buf)))
	if err != nil {
		panic("cannot open NewFsdbWriter")
	}
	for _, col := range([]string{"sid", "sname"}) {
		if err = out.AddCol(col); err != nil {
			panic(fmt.Sprintf("error adding cols: %q", err))
		}
	}
	out.Finalize()
	for _, ct := range sampleClassTable {
		var row []string
		row = append(row, fmt.Sprintf("%v", ct.Sid), ct.Name)
		if err = out.WriteRow(row); err != nil {
			panic(fmt.Sprintf("error writing rows: %q", err))
		}
        }
	out.Close()
}

func ExampleFsdbWriter() { //(t *testing.T) {
	out, err := fsdb.NewFsdbWriter(os.Stdout)
	if err != nil {
		panic("cannot open NewFsdbWriter")
	}
	out.SetFSCode("t")
	for _, col := range([]string{"sid", "sname"}) {
		if err = out.AddCol(col); err != nil {
			panic(fmt.Sprintf("error adding cols: %q", err))
		}
	}
	out.Finalize()
	for _, ct := range sampleClassTable {
		var row []string
		row = append(row, fmt.Sprintf("%v", ct.Sid), ct.Name)
		if err = out.WriteRow(row); err != nil {
			panic(fmt.Sprintf("error writing rows: %q", err))
		}
        }
	out.Close()
	// Output:
	// #fsdb -F t sid sname
	// 1	dave
	// 2	john
	// 3	sugata

}

